@@ -1,12 +1,13 @@
 package Koha::Contrib::Sudoc::Converter;
 # ABSTRACT: Classe de base pour convertir les notices
-$Koha::Contrib::Sudoc::Converter::VERSION = '2.04';
+$Koha::Contrib::Sudoc::Converter::VERSION = '2.05';
 use Moose;
 use Modern::Perl;
 
 # Moulinette SUDOC
 has sudoc => ( is => 'rw', isa => 'Koha::Contrib::Sudoc', required => 1 );
 
+has log => ( is => 'rw', isa => 'Log::Dispatch' );
 
 has item => ( is => 'rw', isa => 'HashRef' );
 
@@ -203,7 +204,7 @@ Koha::Contrib::Sudoc::Converter - Classe de base pour convertir les notices
 
 =head1 VERSION
 
-version 2.04
+version 2.05
 
 =head1 DESCRIPTION
 
@@ -224,6 +225,10 @@ notice ou d'une notice qui existe déjà dans Koha:
 
 =head1 ATTRIBUTES
 
+=head2 log
+
+Logger L<Log::Dispatch> hérité de la classe parente L<Koha::Contrib::Sudoc::Loader>.
+
 =head2 item
 
 Les exemplaires courants. 
