@@ -1,6 +1,6 @@
 package Koha::Contrib::Sudoc::Loader;
 # ABSTRACT: Classe de base pour le chargement de notices biblio/autorité
-$Koha::Contrib::Sudoc::Loader::VERSION = '2.04';
+$Koha::Contrib::Sudoc::Loader::VERSION = '2.05';
 use Moose;
 use Modern::Perl;
 use MARC::Moose::Reader::File::Iso2709;
@@ -76,8 +76,8 @@ sub BUILD {
             "Le convertisseur par défaut sera utilisé.\n");
         $class = 'Koha::Contrib::Sudoc::Converter';
     };
-    $class = $class->new( sudoc => $self->sudoc );
-    $self->converter( $class );
+    $class = $class->new(sudoc => $self->sudoc, log => $self->log);
+    $self->converter($class);
 }
 
 
@@ -106,7 +106,7 @@ sub run {
     $self->log->notice(
          "Nombre d'enregistrements traités : " . $self->count . "\n" .
          "Nombre d'enregistrements ajoutés : " . $self->count_added . "\n" .
-         "Nombre d'enregistrements fusionnés :" . $self->count_replaced . "\n" .
+         "Nombre d'enregistrements fusionnés : " . $self->count_replaced . "\n" .
          "Nombre d'enregistrements ignorées : " . $self->count_skipped . "\n"
      );
     $self->log->notice("** Test ** Le fichier " . $self->file . " n'a pas été chargé\n")
@@ -128,7 +128,7 @@ Koha::Contrib::Sudoc::Loader - Classe de base pour le chargement de notices bibl
 
 =head1 VERSION
 
-version 2.04
+version 2.05
 
 =head1 AUTHOR
 
