@@ -1,6 +1,6 @@
 package Koha::Contrib::Sudoc::Loader::Biblios;
 # ABSTRACT: Chargeur de notices biblio
-$Koha::Contrib::Sudoc::Loader::Biblios::VERSION = '2.04';
+$Koha::Contrib::Sudoc::Loader::Biblios::VERSION = '2.05';
 use Moose;
 
 extends 'Koha::Contrib::Sudoc::Loader';
@@ -67,7 +67,7 @@ sub handle_record {
     ($biblionumber, $framework, $koha_record) =
         $self->sudoc->koha->get_biblio_by_ppn( $ppn );
     if ($koha_record) {
-        $self->log->debug("  PPN trouvé dans la notice Koha $biblionumber");
+        $self->log->debug("  PPN trouvé dans la notice Koha $biblionumber\n");
     }
     else {
         # On cherche un 035 avec un $5 contenant un RCR de l'ILN, auquel cas $a contient
@@ -166,7 +166,7 @@ Koha::Contrib::Sudoc::Loader::Biblios - Chargeur de notices biblio
 
 =head1 VERSION
 
-version 2.04
+version 2.05
 
 =head1 AUTHOR
 
